project rename to seatunnel for other files
diff --git a/doctor/sonatype.sbt b/doctor/sonatype.sbt
index 800f8a7..19261b0 100644
--- a/doctor/sonatype.sbt
+++ b/doctor/sonatype.sbt
@@ -1,12 +1,12 @@
 // License of your choice
 licenses := Seq("APL2" -> url("http://www.apache.org/licenses/LICENSE-2.0.txt"))
-homepage := Some(url("https://interestinglab.github.io/earth-fleet/"))
+homepage := Some(url("https://interestinglab.github.io/seatunnel/"))
 scmInfo := Some(
   ScmInfo(
-    url("https://github.com/Interestinglab/earth-fleet"),
-    "scm:git@github.com:Interestinglab/earth-fleet.git"
+    url("https://github.com/Interestinglab/seatunnel"),
+    "scm:git@github.com:Interestinglab/seatunnel.git"
   )
 )
 developers := List(
   Developer(id="interestinglab", name="interestinglab", email="garygaowork@gmail.com", url=url("https://github.com/Interestinglab"))
-)
\ No newline at end of file
+)
diff --git a/plugins/json/files/schemas/demo.json b/plugins/json/files/schemas/demo.json
index 59bf025..cf83c21 100644
--- a/plugins/json/files/schemas/demo.json
+++ b/plugins/json/files/schemas/demo.json
@@ -1,4 +1,4 @@
 {
-  "name": "Earth-fleet",
+  "name": "seatunnel",
   "age": 2
-}
\ No newline at end of file
+}
diff --git a/sonatype.sbt b/sonatype.sbt
index 800f8a7..19261b0 100644
--- a/sonatype.sbt
+++ b/sonatype.sbt
@@ -1,12 +1,12 @@
 // License of your choice
 licenses := Seq("APL2" -> url("http://www.apache.org/licenses/LICENSE-2.0.txt"))
-homepage := Some(url("https://interestinglab.github.io/earth-fleet/"))
+homepage := Some(url("https://interestinglab.github.io/seatunnel/"))
 scmInfo := Some(
   ScmInfo(
-    url("https://github.com/Interestinglab/earth-fleet"),
-    "scm:git@github.com:Interestinglab/earth-fleet.git"
+    url("https://github.com/Interestinglab/seatunnel"),
+    "scm:git@github.com:Interestinglab/seatunnel.git"
   )
 )
 developers := List(
   Developer(id="interestinglab", name="interestinglab", email="garygaowork@gmail.com", url=url("https://github.com/Interestinglab"))
-)
\ No newline at end of file
+)
diff --git a/waterdrop-apis/sonatype.sbt b/waterdrop-apis/sonatype.sbt
index 800f8a7..19261b0 100644
--- a/waterdrop-apis/sonatype.sbt
+++ b/waterdrop-apis/sonatype.sbt
@@ -1,12 +1,12 @@
 // License of your choice
 licenses := Seq("APL2" -> url("http://www.apache.org/licenses/LICENSE-2.0.txt"))
-homepage := Some(url("https://interestinglab.github.io/earth-fleet/"))
+homepage := Some(url("https://interestinglab.github.io/seatunnel/"))
 scmInfo := Some(
   ScmInfo(
-    url("https://github.com/Interestinglab/earth-fleet"),
-    "scm:git@github.com:Interestinglab/earth-fleet.git"
+    url("https://github.com/Interestinglab/seatunnel"),
+    "scm:git@github.com:Interestinglab/seatunnel.git"
   )
 )
 developers := List(
   Developer(id="interestinglab", name="interestinglab", email="garygaowork@gmail.com", url=url("https://github.com/Interestinglab"))
-)
\ No newline at end of file
+)
diff --git a/waterdrop-config/sonatype.sbt b/waterdrop-config/sonatype.sbt
index 800f8a7..19261b0 100644
--- a/waterdrop-config/sonatype.sbt
+++ b/waterdrop-config/sonatype.sbt
@@ -1,12 +1,12 @@
 // License of your choice
 licenses := Seq("APL2" -> url("http://www.apache.org/licenses/LICENSE-2.0.txt"))
-homepage := Some(url("https://interestinglab.github.io/earth-fleet/"))
+homepage := Some(url("https://interestinglab.github.io/seatunnel/"))
 scmInfo := Some(
   ScmInfo(
-    url("https://github.com/Interestinglab/earth-fleet"),
-    "scm:git@github.com:Interestinglab/earth-fleet.git"
+    url("https://github.com/Interestinglab/seatunnel"),
+    "scm:git@github.com:Interestinglab/seatunnel.git"
   )
 )
 developers := List(
   Developer(id="interestinglab", name="interestinglab", email="garygaowork@gmail.com", url=url("https://github.com/Interestinglab"))
-)
\ No newline at end of file
+)
diff --git a/waterdrop-config/src/test/resources/interestinglab/variables.conf b/waterdrop-config/src/test/resources/interestinglab/variables.conf
index bc432b7..da3b42f 100644
--- a/waterdrop-config/src/test/resources/interestinglab/variables.conf
+++ b/waterdrop-config/src/test/resources/interestinglab/variables.conf
@@ -1,7 +1,7 @@
 spark {
   spark.streaming.batchDuration = 5
 
-  spark.app.name = "Earth-fleet"
+  spark.app.name = "seatunnel"
   spark.executor.instances = 2
   spark.executor.cores = 1
   spark.executor.memory = "1g"
diff --git a/waterdrop-core/sonatype.sbt b/waterdrop-core/sonatype.sbt
index 800f8a7..19261b0 100644
--- a/waterdrop-core/sonatype.sbt
+++ b/waterdrop-core/sonatype.sbt
@@ -1,12 +1,12 @@
 // License of your choice
 licenses := Seq("APL2" -> url("http://www.apache.org/licenses/LICENSE-2.0.txt"))
-homepage := Some(url("https://interestinglab.github.io/earth-fleet/"))
+homepage := Some(url("https://interestinglab.github.io/seatunnel/"))
 scmInfo := Some(
   ScmInfo(
-    url("https://github.com/Interestinglab/earth-fleet"),
-    "scm:git@github.com:Interestinglab/earth-fleet.git"
+    url("https://github.com/Interestinglab/seatunnel"),
+    "scm:git@github.com:Interestinglab/seatunnel.git"
   )
 )
 developers := List(
   Developer(id="interestinglab", name="interestinglab", email="garygaowork@gmail.com", url=url("https://github.com/Interestinglab"))
-)
\ No newline at end of file
+)
diff --git a/bin/utils/app.sh b/bin/utils/app.sh
index 83a0821..d85cffd 100644
--- a/bin/utils/app.sh
+++ b/bin/utils/app.sh
@@ -1,5 +1,5 @@
 #!/usr/bin/env bash
 # Get App Name of Earth-fleet
 function getAppName {
 
     if [ "$#" -ne 1 ]; then
@@ -13,7 +13,7 @@
     # remove all leading and trailing  whitespace
     app_name_config=$(echo ${app_name_config} | tr -d '[:space:]')
 
-    DEFAULT_APP_NAME="Earth-fleet"
+    DEFAULT_APP_NAME="seatunnel"
     APP_NAME=${DEFAULT_APP_NAME}
 
     if [[ ${app_name_config} == \#* ]]; then
@@ -30,4 +30,4 @@
     fi
 
     echo ${APP_NAME}
-}
\ No newline at end of file
+}
@@ -1,5 +1,5 @@
 #!/usr/bin/env bash
-# Get App Name of Earth-fleet
+# Get App Name of seatunnel
 function getAppName {
 